==> pact_ffi-0.1.1.crate: pact_ffi-0.1.1/CHANGELOG.md <==
To generate the log, run `git log --pretty='* %h - %s (%an, %ad)' TAGNAME..HEAD .` replacing TAGNAME and HEAD as appropriate.

# 0.1.1 - Support V4 synchronous messages + protobuf plugin

* 5d974c4a - chore: update to latest models and plugin driver crates (Ronald Holshausen, Tue Nov 16 11:56:53 2021 +1100)
* 19beb0ea - feat(plugins): add support for synch messages via FFI (Ronald Holshausen, Tue Nov 16 10:06:07 2021 +1100)
* df23ba3d - fix: allow multiple consumer version selectors (Matt Fellows, Mon Nov 15 14:28:04 2021 +1100)
* 7c150c8b - feat(plugins): Support message tests via FFI that use plugins (Ronald Holshausen, Wed Nov 10 17:03:49 2021 +1100)
* 20643590 - feat(plugins): add plugin support to FFI functions (Ronald Holshausen, Tue Nov 9 16:06:01 2021 +1100)
* 62f7d36c - refactor: moved the message consumer FFI functions to the handles module (Ronald Holshausen, Mon Nov 8 17:42:26 2021 +1100)
* 0cb367d9 - refactor: moved the HTTP consumer FFI functions to the handles module (Ronald Holshausen, Mon Nov 8 17:25:16 2021 +1100)
* 2027537d - refactor: update FFI to use V4 models internally (Ronald Holshausen, Mon Nov 8 16:44:39 2021 +1100)
* e1ff90c7 - bump version to 0.1.1 (Ronald Holshausen, Thu Nov 4 17:23:32 2021 +1100)

# 0.1.0 - Pact V4 release

* 59e21413 - feat: Pact V4 release (Ronald Holshausen, Thu Nov 4 16:54:56 2021 +1100)
* 400a1231 - chore: drop beta from pact_verifier version (Ronald Holshausen, Thu Nov 4 15:56:22 2021 +1100)
* fc4580b8 - chore: drop beta from pact_mock_server version (Ronald Holshausen, Thu Nov 4 15:28:51 2021 +1100)
* bd2bd0ec - chore: drop beta from pact_matching version (Ronald Holshausen, Wed Nov 3 13:28:35 2021 +1100)
* 296b4370 - chore: update project to Rust 2021 edition (Ronald Holshausen, Fri Oct 22 10:44:48 2021 +1100)
* a561f883 - chore: use the non-beta models crate (Ronald Holshausen, Thu Oct 21 18:10:27 2021 +1100)
* 0c72c80e - chore: fixes after merging from master (Ronald Holshausen, Wed Oct 20 14:46:54 2021 +1100)
* ec265d83 - Merge branch 'master' into feat/plugins (Ronald Holshausen, Wed Oct 20 14:40:37 2021 +1100)
* 2ac17234 - chore: deprecate the old verifier functions (Ronald Holshausen, Tue Oct 19 17:42:56 2021 +1100)
* e98a91fe - chore: update to latest verifier lib (Ronald Holshausen, Tue Oct 19 17:42:07 2021 +1100)
* a3d321cb - chore: update to latest mock server crate (Ronald Holshausen, Tue Oct 19 17:28:24 2021 +1100)
* 46a404c0 - chore: update to latest pact matching crate (Ronald Holshausen, Tue Oct 19 17:20:27 2021 +1100)
* 918e5beb - fix: update to latest models and plugin driver crates (Ronald Holshausen, Tue Oct 19 17:09:48 2021 +1100)
* 7e209367 - chore: update to latest verification crate (Ronald Holshausen, Tue Oct 19 11:50:57 2021 +1100)
* 3819522d - chore: update to the latest matching and mock server crates (Ronald Holshausen, Tue Oct 19 11:34:18 2021 +1100)
* bfa04370 - fix: display the error message when the verification can not be run due to an error (Ronald Holshausen, Tue Oct 19 11:09:21 2021 +1100)
* df386c8a - chore: use the published version of pact-plugin-driver (Ronald Holshausen, Mon Oct 18 13:41:36 2021 +1100)
* 1dc6f543 - chore: bump pact_mock_server version (Ronald Holshausen, Tue Oct 12 16:36:51 2021 +1100)
* 9bbbb52e - chore: bump pact matching crate version (Ronald Holshausen, Tue Oct 12 16:24:01 2021 +1100)
* 35ff0993 - feat: record the version of the lib that created the pact in the metadata (Ronald Holshausen, Tue Oct 12 14:52:43 2021 +1100)
* 1eb37c13 - chore: use the published version of the models crate (Ronald Holshausen, Thu Oct 7 10:49:11 2021 +1100)
* 2e86c48d - Merge pull request #154 from pact-foundation/feat/xml-matchers (Matt Fellows, Tue Oct 5 16:39:18 2021 +1100)
* 9a2049c2 - feat: support XML bodies in FFI interface (Matt Fellows, Thu Sep 30 22:08:01 2021 +1000)
* d171edfd - feat: support provider branches (Matt Fellows, Wed Sep 29 22:47:21 2021 +1000)
* 6d23796f - feat(plugins): support each key and each value matchers (Ronald Holshausen, Wed Sep 29 11:10:46 2021 +1000)
* 6f20282d - Merge branch 'master' into feat/plugins (Ronald Holshausen, Tue Sep 28 14:51:34 2021 +1000)
* a8f900ab - bump version to 0.0.4 (Ronald Holshausen, Tue Sep 28 14:09:57 2021 +1000)
* 7a3c7693 - Merge branch 'master' into feat/plugins (Ronald Holshausen, Mon Sep 20 13:44:53 2021 +1000)
* b71dcabf - refactor(plugins): rename ContentTypeOverride -> ContentTypeHint (Ronald Holshausen, Tue Sep 14 15:08:52 2021 +1000)
* f55440c6 - chore: Bump verifier lib version to 0.11.0-beta.0 (Ronald Holshausen, Mon Sep 13 12:04:19 2021 +1000)
* 03ebe632 - Merge branch 'master' into feat/plugins (Ronald Holshausen, Mon Sep 13 12:01:13 2021 +1000)
* fd6f8f40 - chore: Bump pact_mock_server version to 0.8.0-beta.0 (Ronald Holshausen, Mon Sep 13 11:46:11 2021 +1000)
* 716809f6 - chore: Get CI build passing (Ronald Holshausen, Fri Sep 10 14:55:46 2021 +1000)
* ceb1c35f - Merge branch 'master' into feat/plugins (Ronald Holshausen, Tue Sep 7 10:07:45 2021 +1000)
* e8ae81b3 - refactor: matching req/res with plugins requires data from the pact and interaction (Ronald Holshausen, Thu Sep 2 11:57:50 2021 +1000)
* b9aa7ecb - feat(Plugins): allow plugins to override text/binary format of the interaction content (Ronald Holshausen, Mon Aug 30 10:48:04 2021 +1000)
* 0c5cede2 - chore: bump models crate to 0.2 (Ronald Holshausen, Mon Aug 23 12:56:14 2021 +1000)
* 248629e1 - chore: fix build after merge from master (Ronald Holshausen, Mon Aug 23 10:42:44 2021 +1000)
* 75e13fd8 - Merge branch 'master' into feat/plugins (Ronald Holshausen, Mon Aug 23 10:33:45 2021 +1000)
* b75fea5d - Merge branch 'master' into feat/plugins (Ronald Holshausen, Wed Aug 18 12:27:41 2021 +1000)
* 2662241e - feat(plugins): Call out to plugins when comparing content owned by the plugin during verification (Ronald Holshausen, Fri Aug 13 14:29:30 2021 +1000)
* bdfc6f02 - feat(plugins): Load required plugins when verifying a V4 pact (Ronald Holshausen, Wed Aug 11 14:23:54 2021 +1000)
* dfe3cd42 - chore: bump minor version of Pact verifier libs (Ronald Holshausen, Mon Aug 9 15:10:47 2021 +1000)

# 0.0.3 - support native TLS certs + updated verifier FFI functions

* 42be9eb8 - feat: add FFI functions to extract logs from a verifcation run (Ronald Holshausen, Tue Sep 28 12:48:40 2021 +1000)
* 40cf1ab9 - chore: mark pactffi_logger_attach_sink as unsafe #148 (Ronald Holshausen, Fri Sep 24 11:36:38 2021 +1000)
* ab89152e - Merge pull request #150 from tienvx/make-state-change-url-optional (Ronald Holshausen, Tue Sep 21 09:20:54 2021 +1000)
* df715cd5 - feat: support native TLS. Fixes #144 (Matt Fellows, Mon Sep 20 13:00:33 2021 +1000)
* 339a9504 - feat: make state change url optional (tienvx, Mon Sep 20 12:13:29 2021 +0700)
* dab70272 - feat: add verifier ffi function set consumer filters (tienvx, Tue Sep 14 23:47:14 2021 +0700)
* 36f7e477 - fix: fix missing last tag (tienvx, Tue Sep 14 23:51:02 2021 +0700)
* 4e02722e - Handle required and optional parameters (tienvx, Fri Sep 10 21:56:45 2021 +0700)
* ad73c9af - Extract function get_tags to reuse code (tienvx, Fri Sep 10 21:55:36 2021 +0700)
* 05f4c3de - feat: add verifier ffi function set verification options (tienvx, Wed Sep 8 23:48:13 2021 +0700)
* 971b980e - chore: fix clippy warnings (Ronald Holshausen, Fri Sep 10 17:31:16 2021 +1000)
* 0bb96329 - chore: fix clippy warnings (Ronald Holshausen, Fri Sep 10 17:15:17 2021 +1000)
* b8e51313 - Merge pull request #137 from tienvx/ffi-function-update-provider-state (Ronald Holshausen, Sat Sep 4 13:04:50 2021 +1000)
* 47e940a8 - test(ffi verifier): remove unused import (Mike Geeves, Tue Aug 31 10:11:37 2021 +0100)
* d5167056 - feat(ffi verifier cli): simplify duplicated conversion for default_value, env, possible_values (Mike Geeves, Mon Aug 30 21:29:34 2021 +0100)
* fd9ea9c3 - feat(ffi verifier cli): attributes long/short/help can be simplified (Mike Geeves, Mon Aug 30 21:06:23 2021 +0100)
* 9e582360 - chore: add verifier ffi function update provider state (tienvx, Sun Aug 29 22:20:28 2021 +0700)
* 55985d0a - feat(ffi verifier cli): add in support for ENVs (Mike Geeves, Fri Aug 27 15:59:56 2021 +0100)
* 4a5cdb82 - Merge branch 'master' into feat/ffi_arguments (Mike Geeves, Fri Aug 27 09:57:52 2021 +0100)
* 84957fb9 - feat(ffi verifier cli): verify we can deserialize the json from cli_args, and there are some args (Mike Geeves, Fri Aug 27 09:55:24 2021 +0100)
* 906661cb - feat(ffi verifier cli): split out flags and options (Mike Geeves, Thu Aug 26 11:45:18 2021 +0100)
* 491c23fb - feat(ffi verifier): add multiple to CLI JSON output (Mike Geeves, Wed Aug 25 15:58:00 2021 +0100)
* 46135a16 - chore: add verifier FFI functions for directory, URL and Pact broker sources (Ronald Holshausen, Tue Aug 24 10:14:46 2021 +1000)
* bbae32da - feat(ffi verify): add in default values, start looking at flags (Mike Geeves, Tue Aug 24 00:25:56 2021 +0100)
* ffcabb63 - feat(ffi verifier): add possible_values (Mike Geeves, Mon Aug 23 10:21:16 2021 +0100)
* 5a32f04d - feat(ffi verifier): bump serde version to latest (Mike Geeves, Mon Aug 23 09:55:31 2021 +0100)
* f64b0ead - feat(ffi verifier): revert unwanted changes (Mike Geeves, Mon Aug 23 09:53:31 2021 +0100)
* e8247e55 - feat(ffi verifier): merge master, fix conflicts (Mike Geeves, Mon Aug 23 09:51:24 2021 +0100)
* e557ce27 - feat(ffi verifier): move pactffi_verifier_cli_args to mod.rs, tidy, add docs (Mike Geeves, Mon Aug 23 09:45:54 2021 +0100)
* 4982bfc7 - chore: update FFI readme (Ronald Holshausen, Mon Aug 23 10:31:08 2021 +1000)
* f8d98dcb - feat(ffi verifier): added a crude method to pull out CLI arguments, and make available via FFI (Mike Geeves, Sun Aug 22 19:45:42 2021 +0100)
* 50fcd409 - chore: re-enable cmake build for pact-ffi (Ronald Holshausen, Sun Aug 22 16:20:25 2021 +1000)
* eaefe4d2 - chore: correct the conan recipes (Ronald Holshausen, Sun Aug 22 16:18:50 2021 +1000)
* 72125560 - bump version to 0.0.3 (Ronald Holshausen, Sun Aug 22 15:51:25 2021 +1000)

# 0.0.2 - Bugfix Release

* 9370327c - feat(FFI): Added initial verifier FFI prototype (Ronald Holshausen, Sun Aug 22 15:01:17 2021 +1000)
* c274ca1a - fix: use the pacts for verification endpoint if the conusmer selectors are specified #133 (Ronald Holshausen, Sun Aug 22 11:51:22 2021 +1000)
* 3215821e - chore: correct the OSX release (Ronald Holshausen, Tue Aug 17 12:47:20 2021 +1000)
* 64cf38e9 - bump version to 0.0.2 (Ronald Holshausen, Tue Aug 17 11:00:54 2021 +1000)

# 0.0.1 - M1 architecture support + Bugfixes

* a9940325 - chore: release m1 arm package for new Mac hardware (Matt Fellows, Wed Aug 11 22:57:46 2021 +1000)
* b5a7b779 - feat: support new selectors (Matt Fellows, Mon Aug 9 13:27:33 2021 +1000)
* 8bcd1c7e - fix: min/max type matchers must not apply the limits when cascading (Ronald Holshausen, Sun Aug 8 15:50:40 2021 +1000)
* 738e9961 - chore: generate both a C and C++ header (Ronald Holshausen, Sun Aug 8 14:28:11 2021 +1000)
* 6124ed0b - refactor: Introduce DocPath struct for path expressions (Caleb Stepanian, Thu Jul 29 12:27:32 2021 -0400)
* 9baa714d - chore: bump minor version of matching crate (Ronald Holshausen, Fri Jul 23 14:03:20 2021 +1000)
* 533c9e1f - chore: bump minor version of the Pact models crate (Ronald Holshausen, Fri Jul 23 13:15:32 2021 +1000)
* 3dccf866 - refacfor: moved the pact structs to the models crate (Ronald Holshausen, Sun Jul 18 16:58:14 2021 +1000)
* 372cbdd1 - chore: remove CMake step from CI build (Ronald Holshausen, Sun Jul 18 15:57:30 2021 +1000)
* 996761a6 - chore: remove CMake step from CI build (Ronald Holshausen, Sun Jul 18 15:26:31 2021 +1000)
* 685a2df2 - chore: cmake is failing on CI to find cargo (Ronald Holshausen, Sun Jul 18 15:12:51 2021 +1000)
* e8046d84 - refactor: moved interaction structs to the models crate (Ronald Holshausen, Sun Jul 18 14:36:03 2021 +1000)
* 0c528ea0 - chore: update pact_ffi readme (Ronald Holshausen, Mon Jul 12 15:28:53 2021 +1000)
* 95c873ec - chore: correct conan packages (Ronald Holshausen, Mon Jul 12 11:18:44 2021 +1000)
* bd989b8f - chore: add homepage and repositry URL to FFI manifest (Ronald Holshausen, Mon Jul 12 10:25:36 2021 +1000)
* 5e725866 - chore: add conan publish to release script (Ronald Holshausen, Mon Jul 12 10:23:33 2021 +1000)
* 6d1ff318 - fix: conan packages for pact_ffi (Ronald Holshausen, Mon Jul 12 09:23:48 2021 +1000)
* d7079e43 - bump version to 0.0.1 (Ronald Holshausen, Sun Jul 11 17:47:18 2021 +1000)

# 0.0.0 - Initial Release

==> pact_ffi-0.1.2.crate: pact_ffi-0.1.2/CHANGELOG.md <==
To generate the log, run `git log --pretty='* %h - %s (%an, %ad)' TAGNAME..HEAD .` replacing TAGNAME and HEAD as appropriate.

# 0.1.2 - Bugfix Release

* 631167fa - chore: update to latest mock server crate (Ronald Holshausen, Wed Nov 17 15:13:32 2021 +1100)
* 87e7f11e - chore: remove note from pactffi_write_pact_file (Ronald Holshausen, Wed Nov 17 14:55:22 2021 +1100)
* 5d4a09c6 - feat: store the pact specification version with the mock server (Ronald Holshausen, Wed Nov 17 14:46:56 2021 +1100)
* 4ccc5d02 - chore: update doc comment on pactffi_write_pact_file (Ronald Holshausen, Wed Nov 17 14:04:59 2021 +1100)
* 675506e1 - feat: add pactffi_pact_handle_write_file which knows about the spec version (Ronald Holshausen, Wed Nov 17 13:58:45 2021 +1100)
* 09f3b888 - refactor: make the pact handle types opaque (Ronald Holshausen, Wed Nov 17 13:27:06 2021 +1100)
* aff4d301 - fix: FFI always detects + stores JSON bodies as plain text (Matt Fellows, Tue Nov 16 23:02:12 2021 +1100)
* fc5be202 - fix: update to latest driver crate (Ronald Holshausen, Tue Nov 16 16:19:02 2021 +1100)
* e4a445ba - fix: race condition when shutting down plugin via FFI (Ronald Holshausen, Tue Nov 16 16:01:18 2021 +1100)
* f3c5e7c1 - bump version to 0.1.2 (Ronald Holshausen, Tue Nov 16 14:04:54 2021 +1100)

# 0.1.1 - Support V4 synchronous messages + protobuf plugin

* 5d974c4a - chore: update to latest models and plugin driver crates (Ronald Holshausen, Tue Nov 16 11:56:53 2021 +1100)
* 19beb0ea - feat(plugins): add support for synch messages via FFI (Ronald Holshausen, Tue Nov 16 10:06:07 2021 +1100)
* df23ba3d - fix: allow multiple consumer version selectors (Matt Fellows, Mon Nov 15 14:28:04 2021 +1100)
* 7c150c8b - feat(plugins): Support message tests via FFI that use plugins (Ronald Holshausen, Wed Nov 10 17:03:49 2021 +1100)
* 20643590 - feat(plugins): add plugin support to FFI functions (Ronald Holshausen, Tue Nov 9 16:06:01 2021 +1100)
* 62f7d36c - refactor: moved the message consumer FFI functions to the handles module (Ronald Holshausen, Mon Nov 8 17:42:26 2021 +1100)
* 0cb367d9 - refactor: moved the HTTP consumer FFI functions to the handles module (Ronald Holshausen, Mon Nov 8 17:25:16 2021 +1100)
* 2027537d - refactor: update FFI to use V4 models internally (Ronald Holshausen, Mon Nov 8 16:44:39 2021 +1100)
* e1ff90c7 - bump version to 0.1.1 (Ronald Holshausen, Thu Nov 4 17:23:32 2021 +1100)

# 0.1.0 - Pact V4 release

* 59e21413 - feat: Pact V4 release (Ronald Holshausen, Thu Nov 4 16:54:56 2021 +1100)
* 400a1231 - chore: drop beta from pact_verifier version (Ronald Holshausen, Thu Nov 4 15:56:22 2021 +1100)
* fc4580b8 - chore: drop beta from pact_mock_server version (Ronald Holshausen, Thu Nov 4 15:28:51 2021 +1100)
* bd2bd0ec - chore: drop beta from pact_matching version (Ronald Holshausen, Wed Nov 3 13:28:35 2021 +1100)
* 296b4370 - chore: update project to Rust 2021 edition (Ronald Holshausen, Fri Oct 22 10:44:48 2021 +1100)
* a561f883 - chore: use the non-beta models crate (Ronald Holshausen, Thu Oct 21 18:10:27 2021 +1100)
* 0c72c80e - chore: fixes after merging from master (Ronald Holshausen, Wed Oct 20 14:46:54 2021 +1100)
* ec265d83 - Merge branch 'master' into feat/plugins (Ronald Holshausen, Wed Oct 20 14:40:37 2021 +1100)
* 2ac17234 - chore: deprecate the old verifier functions (Ronald Holshausen, Tue Oct 19 17:42:56 2021 +1100)
* e98a91fe - chore: update to latest verifier lib (Ronald Holshausen, Tue Oct 19 17:42:07 2021 +1100)
* a3d321cb - chore: update to latest mock server crate (Ronald Holshausen, Tue Oct 19 17:28:24 2021 +1100)
* 46a404c0 - chore: update to latest pact matching crate (Ronald Holshausen, Tue Oct 19 17:20:27 2021 +1100)
* 918e5beb - fix: update to latest models and plugin driver crates (Ronald Holshausen, Tue Oct 19 17:09:48 2021 +1100)
* 7e209367 - chore: update to latest verification crate (Ronald Holshausen, Tue Oct 19 11:50:57 2021 +1100)
* 3819522d - chore: update to the latest matching and mock server crates (Ronald Holshausen, Tue Oct 19 11:34:18 2021 +1100)
* bfa04370 - fix: display the error message when the verification can not be run due to an error (Ronald Holshausen, Tue Oct 19 11:09:21 2021 +1100)
* df386c8a - chore: use the published version of pact-plugin-driver (Ronald Holshausen, Mon Oct 18 13:41:36 2021 +1100)
* 1dc6f543 - chore: bump pact_mock_server version (Ronald Holshausen, Tue Oct 12 16:36:51 2021 +1100)
* 9bbbb52e - chore: bump pact matching crate version (Ronald Holshausen, Tue Oct 12 16:24:01 2021 +1100)
* 35ff0993 - feat: record the version of the lib that created the pact in the metadata (Ronald Holshausen, Tue Oct 12 14:52:43 2021 +1100)
* 1eb37c13 - chore: use the published version of the models crate (Ronald Holshausen, Thu Oct 7 10:49:11 2021 +1100)
* 2e86c48d - Merge pull request #154 from pact-foundation/feat/xml-matchers (Matt Fellows, Tue Oct 5 16:39:18 2021 +1100)
* 9a2049c2 - feat: support XML bodies in FFI interface (Matt Fellows, Thu Sep 30 22:08:01 2021 +1000)
* d171edfd - feat: support provider branches (Matt Fellows, Wed Sep 29 22:47:21 2021 +1000)
* 6d23796f - feat(plugins): support each key and each value matchers (Ronald Holshausen, Wed Sep 29 11:10:46 2021 +1000)
* 6f20282d - Merge branch 'master' into feat/plugins (Ronald Holshausen, Tue Sep 28 14:51:34 2021 +1000)
* a8f900ab - bump version to 0.0.4 (Ronald Holshausen, Tue Sep 28 14:09:57 2021 +1000)
* 7a3c7693 - Merge branch 'master' into feat/plugins (Ronald Holshausen, Mon Sep 20 13:44:53 2021 +1000)
* b71dcabf - refactor(plugins): rename ContentTypeOverride -> ContentTypeHint (Ronald Holshausen, Tue Sep 14 15:08:52 2021 +1000)
* f55440c6 - chore: Bump verifier lib version to 0.11.0-beta.0 (Ronald Holshausen, Mon Sep 13 12:04:19 2021 +1000)
* 03ebe632 - Merge branch 'master' into feat/plugins (Ronald Holshausen, Mon Sep 13 12:01:13 2021 +1000)
* fd6f8f40 - chore: Bump pact_mock_server version to 0.8.0-beta.0 (Ronald Holshausen, Mon Sep 13 11:46:11 2021 +1000)
* 716809f6 - chore: Get CI build passing (Ronald Holshausen, Fri Sep 10 14:55:46 2021 +1000)
* ceb1c35f - Merge branch 'master' into feat/plugins (Ronald Holshausen, Tue Sep 7 10:07:45 2021 +1000)
* e8ae81b3 - refactor: matching req/res with plugins requires data from the pact and interaction (Ronald Holshausen, Thu Sep 2 11:57:50 2021 +1000)
* b9aa7ecb - feat(Plugins): allow plugins to override text/binary format of the interaction content (Ronald Holshausen, Mon Aug 30 10:48:04 2021 +1000)
* 0c5cede2 - chore: bump models crate to 0.2 (Ronald Holshausen, Mon Aug 23 12:56:14 2021 +1000)
* 248629e1 - chore: fix build after merge from master (Ronald Holshausen, Mon Aug 23 10:42:44 2021 +1000)
* 75e13fd8 - Merge branch 'master' into feat/plugins (Ronald Holshausen, Mon Aug 23 10:33:45 2021 +1000)
* b75fea5d - Merge branch 'master' into feat/plugins (Ronald Holshausen, Wed Aug 18 12:27:41 2021 +1000)
* 2662241e - feat(plugins): Call out to plugins when comparing content owned by the plugin during verification (Ronald Holshausen, Fri Aug 13 14:29:30 2021 +1000)
* bdfc6f02 - feat(plugins): Load required plugins when verifying a V4 pact (Ronald Holshausen, Wed Aug 11 14:23:54 2021 +1000)
* dfe3cd42 - chore: bump minor version of Pact verifier libs (Ronald Holshausen, Mon Aug 9 15:10:47 2021 +1000)

# 0.0.3 - support native TLS certs + updated verifier FFI functions

* 42be9eb8 - feat: add FFI functions to extract logs from a verifcation run (Ronald Holshausen, Tue Sep 28 12:48:40 2021 +1000)
* 40cf1ab9 - chore: mark pactffi_logger_attach_sink as unsafe #148 (Ronald Holshausen, Fri Sep 24 11:36:38 2021 +1000)
* ab89152e - Merge pull request #150 from tienvx/make-state-change-url-optional (Ronald Holshausen, Tue Sep 21 09:20:54 2021 +1000)
* df715cd5 - feat: support native TLS. Fixes #144 (Matt Fellows, Mon Sep 20 13:00:33 2021 +1000)
* 339a9504 - feat: make state change url optional (tienvx, Mon Sep 20 12:13:29 2021 +0700)
* dab70272 - feat: add verifier ffi function set consumer filters (tienvx, Tue Sep 14 23:47:14 2021 +0700)
* 36f7e477 - fix: fix missing last tag (tienvx, Tue Sep 14 23:51:02 2021 +0700)
* 4e02722e - Handle required and optional parameters (tienvx, Fri Sep 10 21:56:45 2021 +0700)
* ad73c9af - Extract function get_tags to reuse code (tienvx, Fri Sep 10 21:55:36 2021 +0700)
* 05f4c3de - feat: add verifier ffi function set verification options (tienvx, Wed Sep 8 23:48:13 2021 +0700)
* 971b980e - chore: fix clippy warnings (Ronald Holshausen, Fri Sep 10 17:31:16 2021 +1000)
* 0bb96329 - chore: fix clippy warnings (Ronald Holshausen, Fri Sep 10 17:15:17 2021 +1000)
* b8e51313 - Merge pull request #137 from tienvx/ffi-function-update-provider-state (Ronald Holshausen, Sat Sep 4 13:04:50 2021 +1000)
* 47e940a8 - test(ffi verifier): remove unused import (Mike Geeves, Tue Aug 31 10:11:37 2021 +0100)
* d5167056 - feat(ffi verifier cli): simplify duplicated conversion for default_value, env, possible_values (Mike Geeves, Mon Aug 30 21:29:34 2021 +0100)
* fd9ea9c3 - feat(ffi verifier cli): attributes long/short/help can be simplified (Mike Geeves, Mon Aug 30 21:06:23 2021 +0100)
* 9e582360 - chore: add verifier ffi function update provider state (tienvx, Sun Aug 29 22:20:28 2021 +0700)
* 55985d0a - feat(ffi verifier cli): add in support for ENVs (Mike Geeves, Fri Aug 27 15:59:56 2021 +0100)
* 4a5cdb82 - Merge branch 'master' into feat/ffi_arguments (Mike Geeves, Fri Aug 27 09:57:52 2021 +0100)
* 84957fb9 - feat(ffi verifier cli): verify we can deserialize the json from cli_args, and there are some args (Mike Geeves, Fri Aug 27 09:55:24 2021 +0100)
* 906661cb - feat(ffi verifier cli): split out flags and options (Mike Geeves, Thu Aug 26 11:45:18 2021 +0100)
* 491c23fb - feat(ffi verifier): add multiple to CLI JSON output (Mike Geeves, Wed Aug 25 15:58:00 2021 +0100)
* 46135a16 - chore: add verifier FFI functions for directory, URL and Pact broker sources (Ronald Holshausen, Tue Aug 24 10:14:46 2021 +1000)
* bbae32da - feat(ffi verify): add in default values, start looking at flags (Mike Geeves, Tue Aug 24 00:25:56 2021 +0100)
* ffcabb63 - feat(ffi verifier): add possible_values (Mike Geeves, Mon Aug 23 10:21:16 2021 +0100)
* 5a32f04d - feat(ffi verifier): bump serde version to latest (Mike Geeves, Mon Aug 23 09:55:31 2021 +0100)
* f64b0ead - feat(ffi verifier): revert unwanted changes (Mike Geeves, Mon Aug 23 09:53:31 2021 +0100)
* e8247e55 - feat(ffi verifier): merge master, fix conflicts (Mike Geeves, Mon Aug 23 09:51:24 2021 +0100)
* e557ce27 - feat(ffi verifier): move pactffi_verifier_cli_args to mod.rs, tidy, add docs (Mike Geeves, Mon Aug 23 09:45:54 2021 +0100)
* 4982bfc7 - chore: update FFI readme (Ronald Holshausen, Mon Aug 23 10:31:08 2021 +1000)
* f8d98dcb - feat(ffi verifier): added a crude method to pull out CLI arguments, and make available via FFI (Mike Geeves, Sun Aug 22 19:45:42 2021 +0100)
* 50fcd409 - chore: re-enable cmake build for pact-ffi (Ronald Holshausen, Sun Aug 22 16:20:25 2021 +1000)
* eaefe4d2 - chore: correct the conan recipes (Ronald Holshausen, Sun Aug 22 16:18:50 2021 +1000)
* 72125560 - bump version to 0.0.3 (Ronald Holshausen, Sun Aug 22 15:51:25 2021 +1000)

# 0.0.2 - Bugfix Release

* 9370327c - feat(FFI): Added initial verifier FFI prototype (Ronald Holshausen, Sun Aug 22 15:01:17 2021 +1000)
* c274ca1a - fix: use the pacts for verification endpoint if the conusmer selectors are specified #133 (Ronald Holshausen, Sun Aug 22 11:51:22 2021 +1000)
* 3215821e - chore: correct the OSX release (Ronald Holshausen, Tue Aug 17 12:47:20 2021 +1000)
* 64cf38e9 - bump version to 0.0.2 (Ronald Holshausen, Tue Aug 17 11:00:54 2021 +1000)

# 0.0.1 - M1 architecture support + Bugfixes

* a9940325 - chore: release m1 arm package for new Mac hardware (Matt Fellows, Wed Aug 11 22:57:46 2021 +1000)
* b5a7b779 - feat: support new selectors (Matt Fellows, Mon Aug 9 13:27:33 2021 +1000)
* 8bcd1c7e - fix: min/max type matchers must not apply the limits when cascading (Ronald Holshausen, Sun Aug 8 15:50:40 2021 +1000)
* 738e9961 - chore: generate both a C and C++ header (Ronald Holshausen, Sun Aug 8 14:28:11 2021 +1000)
* 6124ed0b - refactor: Introduce DocPath struct for path expressions (Caleb Stepanian, Thu Jul 29 12:27:32 2021 -0400)
* 9baa714d - chore: bump minor version of matching crate (Ronald Holshausen, Fri Jul 23 14:03:20 2021 +1000)
* 533c9e1f - chore: bump minor version of the Pact models crate (Ronald Holshausen, Fri Jul 23 13:15:32 2021 +1000)
* 3dccf866 - refacfor: moved the pact structs to the models crate (Ronald Holshausen, Sun Jul 18 16:58:14 2021 +1000)
* 372cbdd1 - chore: remove CMake step from CI build (Ronald Holshausen, Sun Jul 18 15:57:30 2021 +1000)
* 996761a6 - chore: remove CMake step from CI build (Ronald Holshausen, Sun Jul 18 15:26:31 2021 +1000)
* 685a2df2 - chore: cmake is failing on CI to find cargo (Ronald Holshausen, Sun Jul 18 15:12:51 2021 +1000)
* e8046d84 - refactor: moved interaction structs to the models crate (Ronald Holshausen, Sun Jul 18 14:36:03 2021 +1000)
* 0c528ea0 - chore: update pact_ffi readme (Ronald Holshausen, Mon Jul 12 15:28:53 2021 +1000)
* 95c873ec - chore: correct conan packages (Ronald Holshausen, Mon Jul 12 11:18:44 2021 +1000)
* bd989b8f - chore: add homepage and repositry URL to FFI manifest (Ronald Holshausen, Mon Jul 12 10:25:36 2021 +1000)
* 5e725866 - chore: add conan publish to release script (Ronald Holshausen, Mon Jul 12 10:23:33 2021 +1000)
* 6d1ff318 - fix: conan packages for pact_ffi (Ronald Holshausen, Mon Jul 12 09:23:48 2021 +1000)
* d7079e43 - bump version to 0.0.1 (Ronald Holshausen, Sun Jul 11 17:47:18 2021 +1000)

# 0.0.0 - Initial Release
